#
# spec file for package xsd
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xsd
Version:        4.0.0
Release:        lp150.1.10
Summary:        W3C XML schema to C++ data binding compiler
License:        SUSE-GPL-2.0-with-FLOSS-exception
Group:          Development/Languages/C and C++
# http://www.codesynthesis.com/products/xsd/license.xhtml
Url:            http://www.codesynthesis.com/products/xsd/
Source0:        http://www.codesynthesis.com/download/xsd/4.0/%{name}-%{version}+dep.tar.bz2
Source99:       xsd-rpmlintrc
# Rename xsd to xsdcxx
Patch0:         xsdcxx-rename.patch
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libxerces-c-devel > 2.8.0
BuildRequires:  m4
Requires:       libxerces-c-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
CodeSynthesis XSD is an open-source, cross-platform W3C XML Schema to
C++ data binding compiler. Provided with an XML instance specification
(XML Schema), it generates C++ classes that represent the given
vocabulary as well as parsing and serialization code.
You can then access the data stored in XML using types and functions
that semantically correspond to your application domain rather than
dealing with intricacies of reading and writing XML.

%package        doc
Summary:        API documentation files for xsd
Group:          Documentation/Other
Requires:       xsd

%description    doc
This package contains API documentation for xsd.

%prep
%setup -q -n %{name}-%{version}+dep
%patch0 -p1

%build
make verbose=1 CXXFLAGS="%{optflags}" %{?_smp_mflags}

%install
make install_prefix="%{buildroot}%{_prefix}"  install

# Rename xsd to xsdcxx to avoid conflicting with mono-web package.
mv %{buildroot}%{_bindir}/xsd %{buildroot}%{_bindir}/xsdcxx
mv %{buildroot}%{_datadir}/doc/xsd %{buildroot}%{_datadir}/doc/xsdcxx
mv %{buildroot}%{_mandir}/man1/xsd.1 %{buildroot}%{_mandir}/man1/xsdcxx.1

# Remove duplicate docs.
rm -rf %{buildroot}%{_datadir}/doc/libxsd

%fdupes -s %{buildroot}%{_datadir}/doc

%files
%defattr(-,root,root,-)
%doc README xsd/NEWS xsd/LICENSE xsd/GPLv2 xsd/FLOSSE
%{_bindir}/xsdcxx
%{_includedir}/xsd/
%{_mandir}/man1/xsdcxx.1*

%files doc
%defattr(-,root,root,-)
%doc %{_datadir}/doc/xsdcxx

%changelog
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Wed Jul 23 2014 cgiboudeaux@gmx.com
- Update to 4.0.0
  * Drop support for Xerces-C++ <= 2.8.0.
  * Oracle/Berkeley DB XML support has been dropped.
  * New option, --std, specifies the C++ standard that the generated code
    should conform to. Valid values are c++98 (default) and c++11.
  * New option, --fat-type-file, triggers the placement of code corresponding
    to global elements into type files instead of schema files in the file-
    per-type mode. This option is primarily useful when trying to minimize
    the amount of object code that is linked to an executable by packaging
    compiled generated code into a static (archive) library.
  * New option, --generate-dep, triggers the generation of the make
    dependency files (.d) for the generated C++ files. Other options
    controlling dependency generation are: --generate-dep-only,
  - -dep-phony, --dep-target, --dep-suffix, and --dep-regex. For
    details on this functionality, refer to the XSD compiler command
    line manual (man pages).
  * New option, --suppress-assignment, suppresses the generation of copy
    assignment operators for complex types. If this option is specified,
    the copy assignment operators for such types are declared private and
    left unimplemented.
  * New option, --polymorphic-plate, allows the creation of multiple
    polymorphic map plates in the same application. For details, refer
    to the XSD compiler command line manual (man pages).
  See the NEWS file for the complete changelog
- Drop boost1.46-buildfix.patch (no longer needed)
* Wed May  9 2012 cgiboudeaux@gmx.com
- Change license to SUSE-GPL-2.0-with-FLOSS-exception
* Fri May  4 2012 cgiboudeaux@gmx.com
- Update to 3.3.0.1
- Spec cleanup
* Tue Jul 28 2009 kalev@smartlink.ee
- Updated to work with openSUSE
* Mon Jul 27 2009 rel-eng@lists.fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild
* Tue Jul  7 2009 Antti.Andreimann@mail.ee
- Removed redundant PostScript files from the doc package
* Mon Jul  6 2009 Antti.Andreimann@mail.ee
- Added ACE homepage to SPEC file comments
- Added verbose=1 to MAKEFLAGS so compiler flags could be
  verified from build logs.
* Sat Jul  4 2009 Antti.Andreimann@mail.ee
- Changed License tag to clarify which exceptions we are talking about
* Wed May 20 2009 Antti.Andreimann@mail.ee
- Initial RPM release.
